@@ -8,7 +8,7 @@ use cdbc::io::{BufStream, Decode, Encode};
 use cdbc::net::{MaybeTlsStream, Socket};
 use crate::message::{Message, MessageFormat, Notice, Notification, ParameterStatus};
 use crate::{PgConnectOptions, PgDatabaseError, PgSeverity};
-use cogo::std::sync::channel::{Receiver, Sender};
+use mco::std::sync::channel::{Receiver, Sender};
 
 // the stream is a separate type from the connection to uphold the invariant where an instantiated
 // [PgConnection] is a **valid** connection to postgres
