@@ -9,9 +9,9 @@ use either::Either;
 use std::fmt::{self, Debug};
 use std::io;
 use std::str::from_utf8;
-use cogo::{chan, go};
-use cogo::std::sync::channel::{Receiver, Sender};
-use cogo::std::sync::channel;
+use mco::{chan, co};
+use mco::std::sync::channel::{Receiver, Sender};
+use mco::std::sync::channel;
 use cdbc::io::chan_stream::ChanStream;
 
 /// A stream of asynchronous notifications from Postgres.
@@ -148,8 +148,8 @@ impl PgListener {
     /// # Example
     ///
     /// ```rust,no_run
-    /// # use sqlx_core::postgres::PgListener;
-    /// # use sqlx_core::error::Error;
+    /// # use cdbc_pg::PgListener;
+    /// # use cdbc::error::Error;
     /// #
     /// # #[cfg(feature = "_rt-async-std")]
     /// # sqlx_rt::block_on::<_, Result<(), Error>>(async move {
@@ -179,8 +179,8 @@ impl PgListener {
     /// # Example
     ///
     /// ```rust,no_run
-    /// # use sqlx_core::postgres::PgListener;
-    /// # use sqlx_core::error::Error;
+    /// # use cdbc_pg::PgListener;
+    /// # use cdbc::error::Error;
     /// #
     /// # #[cfg(feature = "_rt-async-std")]
     /// # sqlx_rt::block_on::<_, Result<(), Error>>(async move {
@@ -271,7 +271,7 @@ impl Drop for PgListener {
             };
 
             // Unregister any listeners before returning the connection to the pool.
-            go!(fut);
+            co!(fut);
         }
     }
 }
@@ -302,7 +302,7 @@ impl<'c> Executor for &'c mut PgListener {
         &mut self,
         query: &'q str,
         parameters: &'q [PgTypeInfo],
-    ) -> Result<PgStatement<'q>, Error>
+    ) -> Result<PgStatement, Error>
     where
     {
         self.connection().prepare_with(query, parameters)
