@@ -1135,12 +1135,4 @@ impl PartialEq<PgType> for PgType {
             self.name().eq_ignore_ascii_case(other.name())
         }
     }
-}
-
-#[cfg(feature = "any")]
-impl From<PgTypeInfo> for crate::any::AnyTypeInfo {
-    #[inline]
-    fn from(ty: PgTypeInfo) -> Self {
-        crate::any::AnyTypeInfo(crate::any::type_info::AnyTypeInfoKind::Postgres(ty))
-    }
-}
+}
\ No newline at end of file
