@@ -7,6 +7,7 @@ use crate::{
 };
 use cdbc::types::Type;
 use std::mem;
+use std::ops::Deref;
 use time::{Date, Duration};
 
 impl Type<Postgres> for Date {
@@ -24,7 +25,7 @@ impl PgHasArrayType for Date {
 impl Encode<'_, Postgres> for Date {
     fn encode_by_ref(&self, buf: &mut PgArgumentBuffer) -> IsNull {
         // DATE is encoded as the days since epoch
-        let days = (*self - PG_EPOCH).whole_days() as i32;
+        let days = (*self - *PG_EPOCH.deref()).whole_days() as i32;
         Encode::<Postgres>::encode(&days, buf)
     }
 
@@ -39,10 +40,13 @@ impl<'r> Decode<'r, Postgres> for Date {
             PgValueFormat::Binary => {
                 // DATE is encoded as the days since epoch
                 let days: i32 = Decode::<Postgres>::decode(value)?;
-                PG_EPOCH + Duration::days(days.into())
+                *PG_EPOCH.deref() + Duration::days(days.into())
             }
 
-            PgValueFormat::Text => Date::parse(value.as_str()?, "%Y-%m-%d")?,
+            PgValueFormat::Text => {
+                let format = time::format_description::parse("[year]-[month]-[day]")?;
+                Date::parse(value.as_str()?, &format)?
+            },
         })
     }
 }
